@@ -94,11 +94,19 @@ class ContentLoader {
         // insert new items in database
         \F3::get('logger')->log('start item fetching', \DEBUG);
 
+        $itemsInFeed = array();
+        foreach ($spout as $item) {
+            $itemsInFeed[] = $item->getId();
+        }
+        $itemsFound = $this->itemsDao->findAll($itemsInFeed);
+
+
         $lasticon = false;
         foreach ($spout as $item) {
             // item already in database?
-            if($this->itemsDao->exists($item->getId())===true)
+            if (isset($itemsFound[$item->getId()])) {
                 continue;
+            }
             
             // test date: continue with next if item too old
             $itemDate = new \DateTime($item->getDate());
@@ -176,7 +184,7 @@ class ContentLoader {
                 "keep_bad"       => 0,
                 "comment"        => 1,
                 "cdata"          => 1,
-                "elements"       => 'div,p,ul,li,a,img,dl,dt,h1,h2,h3,h4,h5,h6,ol,br,table,tr,td,blockquote,pre,ins,del,th,thead,tbody,b,i,strong,em,tt'
+                "elements"       => 'div,p,ul,li,a,img,dl,dt,dd,h1,h2,h3,h4,h5,h6,ol,br,table,tr,td,blockquote,pre,ins,del,th,thead,tbody,b,i,strong,em,tt'
             )
         );
     }
