@@ -367,18 +367,17 @@ class Web extends Prefab {
 	**/
 	function engine($arg='socket') {
 		$arg=strtolower($arg);
-		if ($arg=='curl' && ($curl=extension_loaded('curl')) ||
-			$arg=='stream' && ($stream=ini_get('allow_url_fopen')) ||
-			$arg=='socket' && ($socket=function_exists('fsockopen')))
-			$this->wrapper=$arg;
-		elseif ($socket)
-			$this->wrapper='socket';
-		elseif ($stream)
-			$this->wrapper='stream';
-		elseif ($curl)
-			$this->wrapper='curl';
-		else
-			user_error(E_Request);
+		$flags=array(
+			'curl'=>extension_loaded('curl'),
+			'stream'=>ini_get('allow_url_fopen'),
+			'socket'=>function_exists('fsockopen')
+		);
+		if ($flags[$arg])
+			return $this->wrapper=$arg;
+		foreach ($flags as $key=>$val)
+			if ($val)
+				return $this->wrapper=$key;
+		user_error(E_Request);
 	}
 
 	/**
@@ -510,7 +509,7 @@ class Web extends Prefab {
 					if ($fw->get('CACHE') &&
 						($cached=$cache->exists(
 							$hash=$fw->hash($save).'.'.$ext[0],$data)) &&
-						$cached>filemtime($save))
+						$cached[0]>filemtime($save))
 						$dst.=$data;
 					else {
 						$data='';
@@ -619,7 +618,7 @@ class Web extends Prefab {
 	}
 
 	/**
-	*	Retrieve RSS/Atom feed and return as an array
+	*	Retrieve RSS feed and return as an array
 	*	@return array|FALSE
 	*	@param $url string
 	*	@param $max int
@@ -637,24 +636,15 @@ class Web extends Prefab {
 		$out=array();
 		if (isset($xml->channel)) {
 			$out['source']=(string)$xml->channel->title;
+			$max=min($max,count($xml->channel->item));
 			for ($i=0;$i<$max;$i++) {
 				$item=$xml->channel->item[$i];
-				$out['feed'][]=array(
-					'title'=>(string)$item->title,
-					'link'=>(string)$item->link,
-					'text'=>(string)$item->description
-				);
-			}
-		}
-		elseif (isset($xml->entry)) {
-			$out['source']=(string)$xml->author->name;
-			for ($i=0;$i<$max;$i++) {
-				$item=$xml->entry[$i];
-				$out['feed'][]=array(
-					'title'=>(string)$item->title,
-					'link'=>(string)$item->link['href'],
-					'text'=>(string)$item->summary
-				);
+				$list=array(''=>NULL)+$item->getnamespaces(TRUE);
+				$fields=array();
+				foreach ($list as $ns=>$uri)
+					foreach ($item->children($uri) as $key=>$val)
+						$fields[$ns.($ns?':':'').$key]=(string)$val;
+				$out['feed'][]=$fields;
 			}
 		}
 		else
